@@ -8,34 +8,25 @@ from pytest_lazy_fixtures.lazy_fixture import lf as lazy_fixture
 from semantic_release.cli.commands.main import main
 
 from tests.const import MAIN_PROG_NAME, VERSION_SUBCMD
-from tests.fixtures.repos import (
-    get_versions_for_trunk_only_repo_w_tags,
-    repo_w_trunk_only_angular_commits,
-)
+from tests.fixtures.repos import repo_w_trunk_only_angular_commits
 from tests.util import assert_exit_code
 
 if TYPE_CHECKING:
     from unittest.mock import MagicMock
 
     from click.testing import CliRunner
-    from git import Repo
     from requests_mock import Mocker
 
-    from tests.fixtures.git_repo import GetVersionStringsFn
+    from tests.fixtures.git_repo import BuiltRepoResult, GetVersionsFromRepoBuildDefFn
 
 
 @pytest.mark.parametrize(
-    "repo, get_repo_versions",
-    [
-        (
-            lazy_fixture(repo_w_trunk_only_angular_commits.__name__),
-            lazy_fixture(get_versions_for_trunk_only_repo_w_tags.__name__),
-        )
-    ],
+    "repo_result",
+    [lazy_fixture(repo_w_trunk_only_angular_commits.__name__)],
 )
 def test_version_already_released_when_strict(
-    repo: Repo,
-    get_repo_versions: GetVersionStringsFn,
+    repo_result: BuiltRepoResult,
+    get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
     cli_runner: CliRunner,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
@@ -46,7 +37,10 @@ def test_version_already_released_when_strict(
     Then no version release should happen, which means no code changes, no build, no commit,
     no tag, no push, and no vcs release creation while returning an exit code of 2.
     """
-    latest_release_version = get_repo_versions()[-1]
+    repo = repo_result["repo"]
+    latest_release_version = get_versions_from_repo_build_def(
+        repo_result["definition"]
+    )[-1]
     expected_error_msg = f"[bold orange1]No release will be made, {latest_release_version} has already been released!"
 
     # Setup: take measurement before running the version command
@@ -77,10 +71,10 @@ def test_version_already_released_when_strict(
 
 
 @pytest.mark.parametrize(
-    "repo", [lazy_fixture(repo_w_trunk_only_angular_commits.__name__)]
+    "repo_result", [lazy_fixture(repo_w_trunk_only_angular_commits.__name__)]
 )
 def test_version_on_nonrelease_branch_when_strict(
-    repo: Repo,
+    repo_result: BuiltRepoResult,
     cli_runner: CliRunner,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
@@ -91,6 +85,9 @@ def test_version_on_nonrelease_branch_when_strict(
     Then no version release should happen which means no code changes, no build, no commit,
     no tag, no push, and no vcs release creation while returning an exit code of 2.
     """
+    repo = repo_result["repo"]
+
+    # Setup
     branch = repo.create_head("next").checkout()
     expected_error_msg = (
         f"branch '{branch.name}' isn't in any release groups; no release will be made\n"
